@@ -4,7 +4,7 @@ use Mojolicious::Plugin::AssetPack::Asset::Null;
 use Mojolicious::Plugin::AssetPack::Store;
 use Mojolicious::Plugin::AssetPack::Util qw(diag has_ro load_module DEBUG);
 
-our $VERSION = '1.11';
+our $VERSION = '1.12';
 
 has minify => sub { shift->_app->mode eq 'development' ? 0 : 1 };
 
@@ -220,7 +220,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-1.11
+1.12
 
 =head1 SYNOPSIS
 
@@ -314,7 +314,7 @@ There are some optional modules you might want to install:
 
 =item * L<CSS::Minifier::XS>
 
-Used by L<Mojolicious::Plugin::AssetPack::Pipe::CSS>.
+Used by L<Mojolicious::Plugin::AssetPack::Pipe::Css>.
 
 =item * L<CSS::Sass>
 
